@@ -324,29 +324,13 @@ class VolumeManifest(object):
         """
         meta = self.getMetadata()
         try:
-            meta[str(key)] = str(value)
+            meta[key] = value
             self.setMetadata(meta)
         except Exception:
             self.log.error("Volume.setMetaParam: %s: %s=%s" %
                            (self.volUUID, key, value))
             raise
 
-    @classmethod
-    def formatMetadata(cls, meta):
-        """
-        Format metadata string in storage format.
-
-        Raises MetadataOverflowError if formatted metadata is too long.
-        """
-        # TODO: Adopt VolumeMetadata.storage_format()
-        lines = ["%s=%s\n" % (key.strip(), str(value).strip())
-                 for key, value in meta.iteritems()]
-        lines.append("EOF\n")
-        data = "".join(lines)
-        if len(data) > sc.METADATA_SIZE:
-            raise se.MetadataOverflowError(data)
-        return data
-
     @deprecated  # valid for domain version < 3
     def setrw(self, rw):
         # Since domain version 3 (V3) VDSM is not changing the internal volumes
@@ -531,7 +515,11 @@ class VolumeManifest(object):
     @classmethod
     def newMetadata(cls, metaId, sdUUID, imgUUID, puuid, size, format, type,
                     voltype, disktype, desc="", legality=sc.ILLEGAL_VOL):
-        meta = VolumeMetadata(sdUUID, imgUUID, puuid, size, format, type,
+        # TODO: VolumeMetadata now operates in bytes and we temporary
+        # convert blocks to bytes there. Needs to be fixed, when
+        # all the volume code will be converted to bytes.
+        capacity = size * sc.BLOCK_SIZE_512
+        meta = VolumeMetadata(sdUUID, imgUUID, puuid, capacity, format, type,
                               voltype, disktype, desc, legality)
         cls.createMetadata(metaId, meta)
         return meta
@@ -692,7 +680,7 @@ class VolumeManifest(object):
         raise NotImplementedError
 
     @classmethod
-    def _putMetadata(cls, metaId, meta):
+    def _putMetadata(cls, metaId, meta, **overrides):
         raise NotImplementedError
 
     @classmethod
@@ -738,7 +726,7 @@ class VolumeManifest(object):
     def getVolumeTrueSize(self):
         raise NotImplementedError
 
-    def setMetadata(self, meta, metaId=None):
+    def setMetadata(self, meta, metaId=None, **overrides):
         raise NotImplementedError
 
     @deprecated  # valid only for domain version < 3, see volume.setrw
@@ -754,12 +742,6 @@ class VolumeManifest(object):
     def _share(self, dstImgPath):
         raise NotImplementedError
 
-    def _getMetaVolumePath(self, vol_path=None):
-        raise NotImplementedError
-
-    def _getLeaseVolumePath(self, vol_path=None):
-        raise NotImplementedError
-
     # Implemented only in block storage
 
     def getDevPath(self):
@@ -783,7 +765,7 @@ class VolumeManifest(object):
     def setParentTag(self, puuid):
         raise NotImplementedError
 
-    def getMetaOffset(self):
+    def getMetaSlot(self):
         raise NotImplementedError
 
 
@@ -863,15 +845,11 @@ class Volume(object):
         return self._manifest._share(dstImgPath)
 
     @classmethod
-    def formatMetadata(cls, meta):
-        return cls.manifestClass.formatMetadata(meta)
+    def _putMetadata(cls, metaId, meta, **overrides):
+        cls.manifestClass._putMetadata(metaId, meta, **overrides)
 
-    @classmethod
-    def _putMetadata(cls, metaId, meta):
-        cls.manifestClass._putMetadata(metaId, meta)
-
-    def setMetadata(self, meta, metaId=None):
-        return self._manifest.setMetadata(meta, metaId)
+    def setMetadata(self, meta, metaId=None, **overrides):
+        return self._manifest.setMetadata(meta, metaId, **overrides)
 
     @classmethod
     def _getModuleAndClass(cls):
@@ -1130,7 +1108,7 @@ class Volume(object):
             'size' - in blocks
             'volFormat' - volume format COW / RAW
             'preallocate' - Preallocate / Sparse
-            'diskType' - enum (vdsm.API.Image.DiskTypes)
+            'diskType' - enum (vdsm.storage.constants.VOL_DISKTYPE)
             'srcImgUUID' - source image UUID
             'srcVolUUID' - source volume UUID
             'initialSize' - initial volume size in blocks,
